﻿using UnityEngine;
using UnityEditor;

[CustomPropertyDrawer(typeof(SeparatorAttribute))]
public class SeparatorDrawer : PropertyDrawer
{
	const int lineHeight = 1;
	const int separatorHeight = 20;

	public override float GetPropertyHeight(SerializedProperty property, GUIContent label)
	{
		return EditorGUI.GetPropertyHeight(property, label, true) + separatorHeight;
	}

	public override void OnGUI(Rect position, SerializedProperty property, GUIContent label)
	{
		Rect line = position;
		line.y = position.y + (separatorHeight - lineHeight) / 2f;
		line.height = lineHeight;
		EditorGUI.DrawRect(line, EditorGUIExtras.LineColor);
		
		position.y += separatorHeight;
		EditorGUI.PropertyField(position, property, label, true);
	}
}