﻿using UnityEditor;
using UnityEngine;

/// <summary>
/// Suffixes EditorOnly Hierarchy items with miniLabels
/// Hacks into drawing EditorOnly '---' separator GameObjects created with HierarchySeparator
/// </summary>
[InitializeOnLoad]
public class HierarchyMarkEditorOnlyGOs
{
	const string editorOnlyTag = "EditorOnly";
	
	
	// EditorOnly Separators
	const string separatorName = "---";
	private static readonly float separatorLeftOffset = EditorGUIUtility.singleLineHeight + 3;

	// Any GameObjects tagged as EditorOnly
	private const string eoLabel = "EO";
	private const int eoRightOffset = 16;

	// GameObjects with custom Component GameDevBuildOnly
	//private static Type devComponentType = typeof(GameDevBuildOnly);
	private const string devComponentType = "GameDevBuildOnly"; // Using Component name lets us not to include Component in all projects
	private const string devLabel = "DB";
	private const int devRightOffset = 16;



	static HierarchyMarkEditorOnlyGOs()
	{
		EditorApplication.hierarchyWindowItemOnGUI += HierarchyWindowItemOnGUI;
	}
	static void HierarchyWindowItemOnGUI(int instanceID, Rect selectionRect)
	{
		GameObject gameObject = EditorUtility.InstanceIDToObject(instanceID) as GameObject;
		
		if (!gameObject) return;
		
		if (gameObject.CompareTag(editorOnlyTag))
		{
			if (string.Equals(gameObject.name, separatorName))
			{
				RenderAsSeparator(selectionRect);
			}
			else
			{
				MarkItem(selectionRect, eoLabel, eoRightOffset);
			}
		}
		else if (gameObject.GetComponent(devComponentType))
		{
			var component = gameObject.GetComponent(devComponentType) as Behaviour;
			if (component.enabled)
			{
				MarkItem(selectionRect, devLabel, devRightOffset);
			}
		}
	}
	
	
	
	// Overlay with horizontal line
	static void RenderAsSeparator(Rect selectionRect)
	{
		Color defaultGUIColor = GUI.color;
		
		Rect separatorRect = new Rect(selectionRect);
		separatorRect.x += separatorLeftOffset;
		separatorRect.y += selectionRect.height * 0.5f;
		separatorRect.width -= separatorLeftOffset;
		separatorRect.height = 1.5f;
		
		Rect bgRect = new Rect(separatorRect);
		bgRect.x -= 2.5f;
		bgRect.y -= 2.5f;
		bgRect.width += 5;
		bgRect.height += 5;
		GUI.color = EditorGUIExtras.EditorBackgroundColor;
		GUI.DrawTexture(bgRect, EditorGUIUtility.whiteTexture, ScaleMode.StretchToFill);

		GUI.color = EditorGUIExtras.LineColor;
		GUI.DrawTexture(separatorRect, EditorGUIUtility.whiteTexture, ScaleMode.StretchToFill);
		GUI.color = defaultGUIColor;
	}
	// Draw additional minilabel
	static void MarkItem(Rect selectionRect, string label, float rightOffset)
	{
		Rect minilabelRect = new Rect(selectionRect);
		minilabelRect.x += minilabelRect.width - rightOffset;
		GUI.Label(minilabelRect, label, EditorStyles.miniLabel);
	}
}