﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Assertions;

public class Constellation : MonoBehaviour
{
	[ReadOnly]
	public ConstellationStar activeStar;

	[Space]
	public InstrumentSO instrumentDef;

	[Space]
	public List<ConstellationStar> stars;

	[Space]
	public float replayToneDuration = 0.15f;
	
	
	private void Awake()
	{
		
	}
	private void Start()
	{
		stars[0].Activate();
	}
	
	
	
	public int GetStarIndex(ConstellationStar star)
	{
		for (int i=0; i<stars.Count; i++)
		{
			if (stars[i] == star)
				return i;
		}

		Debug.LogError("Star not found in Constellation, this should not happen.");
		return -1;
	}



	public ConstellationStar GetNextStar()
	{
		return GetNextStar(activeStar);
	}
	public ConstellationStar GetNextStar(ConstellationStar originStar)
	{
		ConstellationStar nextStar = null;
		
		bool returnNext = false;
		foreach (var s in stars)
		{
			if (returnNext)
			{
				nextStar = s;
				break;
			}
			
			if (s == originStar) returnNext = true;
		}
		
		return nextStar;
	}
	public bool IsStarLast(ConstellationStar star)
	{
		return (GetNextStar(star) == null);
	}



	public void Completed()
	{
		Debug.Log(this.gameObject.name + " completed.");

		GameController.MarkConstellationAsCompleted(instrumentDef);

		StartCoroutine(CompletedCoroutine());
	}
	IEnumerator CompletedCoroutine()
	{
		yield return new WaitForSeconds(1f);
		
		// Re-play
		for (int i = 0; i < stars.Count; i++)
		{
			stars[i].PlayTone();
			yield return new WaitForSeconds(replayToneDuration);
		}
		
		yield return new WaitForSeconds(1f);
		
		UnityPlayerApp.Scenes.Loft.Load();
	}
}