﻿using System.Collections;
using System.Collections.Generic;
using DG.Tweening;
using UnityEngine;
using UnityEngine.Assertions;

public class ConstellationStar : MonoBehaviour
{
	public ConstellationStarTarget target;
	public ConstellationStarBridge bridge;


	[Space]
	public SpriteRenderer mainVisual;
	public AudioSource audioSource;
	public AudioClip starReachedClip;


	bool active = false;
	public bool Active => active;
	bool dragged = false;

	int starIndex;

	Camera mainCamera;
	Constellation parentConstelation;
	public Constellation ParentConstelation => parentConstelation;


	private void Awake()
	{
		mainCamera = Camera.main;
		parentConstelation = GetComponentInParent<Constellation>();

		starIndex = parentConstelation.GetStarIndex(this);

		target.gameObject.SetActive(false);
		bridge.gameObject.SetActive(false);
		
		Hide();
	}
	private void OnMouseDown()
	{
		if (!active) return;
		if (parentConstelation.IsStarLast(this)) return;
		
		InitiateDrag();
	}
	private void OnMouseUp()
	{
		if (dragged)
		{
			EndDrag(viaMouseUp: true);
		}
	}
	private void Update()
	{
		if (dragged)
		{
			Vector3 cursorScreenPoint = Input.mousePosition;
			Vector3 cursorPosition = mainCamera.ScreenToWorldPoint(cursorScreenPoint).WithZ(0f);
			target.UpdatePosition(cursorPosition);
		}
	}



	public void Activate()
	{
		active = true;
		parentConstelation.activeStar = this;

		Debug.Log(this.gameObject.name + " activated.");

		Reveal();
	}
	public void Deactivate()
	{
		active = false;
	}



	void Hide()
	{
		mainVisual.enabled = false;
	}
	void Reveal()
	{
		mainVisual.sprite =
			parentConstelation.instrumentDef.GetTone(starIndex).constellationVisual;

		mainVisual.enabled = true;
	}
	void Pulse()
	{
		mainVisual.transform.DOPunchScale(Vector3.one * 0.5f, 0.5f, vibrato: 0, elasticity: 0);
	}
	public void PlayTone()
	{
		var audioClip = parentConstelation.instrumentDef.GetTone(starIndex).GetAudioClip(parentConstelation.instrumentDef);
		
		audioSource.PlayOneShot(audioClip);
		Pulse();
	}
	public void PlayStarReachedFX()
	{
		audioSource.PlayOneShot(starReachedClip);
		Pulse();
	}



	public void InitiateDrag()
	{
		dragged = true;

		target.ResetPosition();
		target.gameObject.SetActive(true);
		bridge.gameObject.SetActive(true);
		
		Cursor.visible = false;

		if (starIndex == 0)
		{
			//PlayTone();
		}
	}
	public void EndDrag(bool viaMouseUp)
	{
		dragged = false;

		if (viaMouseUp)
		{
			target.gameObject.SetActive(false);
			bridge.gameObject.SetActive(false);
		}
		
		Cursor.visible = true;
	}

	public void Connect(ConstellationStar targetReachedStar)
	{
		EndDrag(viaMouseUp: false);
		
		target.UpdatePosition(targetReachedStar.transform.position);
		target.gameObject.SetActive(false);
		
		this.Deactivate();
		bridge.Finalized();

		targetReachedStar.Activate();
		targetReachedStar.PlayStarReachedFX();

		var starAfterReachedStar = parentConstelation.GetNextStar(targetReachedStar);
		if (starAfterReachedStar == null)
		{
			parentConstelation.Completed();
		}
	}

}