﻿using System.Collections;
using System.Collections.Generic;
using DG.Tweening;
using UnityEngine;
using UnityEngine.Assertions;

public class ConstellationStarBridge : MonoBehaviour
{
	public Color initialColor = Color.white;

	public LineRenderer lr;
	public float opaqueAlpha = 1f;
	public float transparentAlpha = 0.15f;

	[Space]
	public AudioSource locatorAudioSource;
	public float farVolume = 0.5f;
	public float closeVolume = 1f;
	public float farPitch = -0.15f;
	public float closePitch = 1.15f;

	[Space]
	public Transform origin;
	public Transform target;



	///[AttachAsInspectorButton(AttachAsInspectorButtonAttribute.EnabledState.EditModeOnly)]
	
	public void UpdateAsTargetMoved(Vector3 destinationPos)
	{
		float distance = Vector3.Distance(target.position, destinationPos);
		float distanceParam = Mathf.Clamp01(distance / 5f);

		UpdateLinePoints();
		UpdateLineColor(distanceParam);
		UpdateLocator(distanceParam);
	}
	public void UpdateLinePoints()
	{
		lr.SetPositions(new Vector3[] { origin.position, target.position });
	}
	void UpdateLineColor(float distanceParam)
	{
		
		float alpha = Mathf.Lerp(transparentAlpha, opaqueAlpha, 1 - distanceParam);
		Color color = initialColor.WithAlpha(alpha);
		
		lr.startColor = lr.endColor = color;
	}
	void UpdateLocator(float distanceParam)
	{
		float volume = Mathf.Lerp(farVolume, closeVolume, 1 - distanceParam);
		float pitch = Mathf.Lerp(farPitch, closePitch, 1 - distanceParam);

		locatorAudioSource.volume = volume;
		locatorAudioSource.pitch = pitch;
	}




	public void Finalized()
	{
		lr.startColor = lr.endColor = initialColor.WithAlpha(opaqueAlpha);

		locatorAudioSource.DOFade(0f, 0.25f).OnComplete(() => {
			locatorAudioSource.Stop();
		});
	}
}