﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.Assertions;

public class Multitrack : MonoBehaviour
{
	public static Multitrack Instance { get; private set; }

	public InstrumentTrack baseTrack;
	public List<InstrumentTrack> instrumentTracks;
	
	
	
	private void Awake()
	{
		if (Instance == null) Instance = this;
		else if (Instance != this) Destroy(this.gameObject);
		
		DontDestroyOnLoad(this.gameObject);
	}
	private void Start()
	{
		// Start mute playback
		foreach(var it in instrumentTracks)
		{
			it.Initialize();
		}
	}



	public void BeginBaseTrackPlayback()
	{
		baseTrack.Initialize();
		baseTrack.Introduce(forceFadeIn: true);
	}



	public void IntroduceInstrument(InstrumentSO newInstrumentDef)
	{
		foreach (var it in instrumentTracks)
		{
			if (it.instrumentDef == newInstrumentDef)
			{
				it.Introduce();
			}
		}
	}


	public void FadeOut(float duration)
	{
		baseTrack.FadeOut(duration);
		foreach (var it in instrumentTracks)
		{
			it.FadeOut(duration);
		}
	}
}