﻿using UnityEngine;
using UnityEngine.SceneManagement;

public static partial class UnityPlayerApp
{
	[RuntimeInitializeOnLoadMethod]
	private static void SceneLoadHook()
	{
		SceneManager.sceneLoaded += Scenes.OnSceneLoaded;
		
		// Subscribed delegate ^^^ is called as late as the Scene switches.
		// For the initial Scene being loaded in Player, we call the subscribed Scene.OnSceneLoaded method manually:
		Scenes.OnSceneLoaded(SceneManager.GetActiveScene(), LoadSceneMode.Single);
	}
	
	
	
	public static class Scenes
	{
		public class Scene
		{
			public string Name { get; private set; }
			
			public Scene(string name)
			{
				if (!Application.CanStreamedLevelBeLoaded(name))
				{
					Debug.LogWarning($"Scene called '{name}', referenced in {typeof(UnityPlayerApp)}, is not included in build.");
				}
				
				this.Name = name;
			}
			
			public static implicit operator string(Scene s) => s.Name;
			
			
			public void Load()
			{
				SceneManager.LoadScene(this.Name);
			}
			public AsyncOperation LoadAsync(bool allowSceneActivation = true)
			{
				var asyncOperation = SceneManager.LoadSceneAsync(this.Name);
				asyncOperation.allowSceneActivation = allowSceneActivation;
				return asyncOperation;
			}
			
			
			public bool WasPrevious => PreviouslyLoaded == this.Name;
		}
		
		
		
		public static readonly Scene Loft = new Scene("Loft");
		//public static readonly Scene Home = new Scene("1 Home");
		//public static readonly Scene Game = new Scene("2 Game");
		
		public static string PreviouslyLoaded { get; private set; } = null;
		static string loaded = null;
		
		public static void OnSceneLoaded(UnityEngine.SceneManagement.Scene scene, LoadSceneMode mode)
		{
			PreviouslyLoaded = loaded;
			loaded = scene.name;
			
			//Debug.Log($"OnSceneLoaded: {Loaded} (PreviouslyLoaded = {PreviouslyLoaded ?? "null"})");
		}
		
		
		
		public static void LoadNextScene()
		{
			SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex + 1);
		}
		public static void RestartCurrentScene()
		{
			SceneManager.LoadScene(SceneManager.GetActiveScene().buildIndex);
		}
	}
}