﻿using UnityEngine;

public static partial class UnityPlayerApp
{
	[RuntimeInitializeOnLoadMethod]
	public static void Init()
	{
		// UnityPlayer framerate
		//
		// On iOS limited by default (value -1) to 30.
		// On Android is supposed to be limited too, but it isn't. Setting it make no harm but unnecessary.
		// On WebGL should always be kept on default value (-1), misbehaves when defined.
#if UNITY_IOS
		Application.targetFrameRate = 60;
#endif
	}



	public static void Exit()
	{
#if UNITY_EDITOR
		Debug.Log($"{typeof(UnityPlayerApp)}.Exit() called in Editor. Player stopped.");
		UnityEditor.EditorApplication.isPlaying = false;
#elif UNITY_ANDROID && !UNITY_EDITOR
		using (AndroidJavaClass javaClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
		{
			AndroidJavaObject unityActivity = javaClass.GetStatic<AndroidJavaObject>("currentActivity");
			unityActivity.Call<bool>("moveTaskToBack", true);
		}
#elif UNITY_WEBGL
		return; // Do nothing
#else
		Application.Quit();
#endif
	}



#if UNITY_ANDROID || UNITY_IOS
	public static bool MobilePlatform => true;
	public static bool WebGLPlatform => false;
	public static bool StandalonePlatform => false;
#elif UNITY_WEBGL
	public static bool MobilePlatform => false;
	public static bool WebGLPlatform => true;
	public static bool StandalonePlatform => false;
#elif UNITY_STANDALONE
	public static bool MobilePlatform => false;
	public static bool WebGLPlatform => false;
	public static bool StandalonePlatform => true;
#else
	public static bool MobilePlatform => false;
	public static bool WebGLPlatform => false;
	public static bool StandalonePlatform => false;
#endif
}