﻿//using System.Linq;
using UnityEngine;

public abstract class SingletonScriptableObject<T> : ScriptableObject where T : ScriptableObject
{
	private static T instance = null;
	public static T Instance
	{
		get
		{
			if (!instance)
			{
				// Look for an instance
				//
				// Beware: not referenced ScriptableObjects are not going to be found.
				//
				// Reference this Singleton in any MonoBehaviour,
				// or use provided method to load Asset from Resources folder.
				
				
				//instance = Resources.FindObjectsOfTypeAll<T>().FirstOrDefault(); // Omitting Linq call
				T[] foundInstances = Resources.FindObjectsOfTypeAll<T>();
				
				if (foundInstances != null && foundInstances.Length >= 1)
				{
					instance = foundInstances[0];
				}
			}

			return instance;
		}
	}
	
	
	
	/// <summary>
	/// Tries to assign Instance of SingletonScriptableObject by loading Asset from Resources folder
	/// </summary>
	/// <param name="assetname">Name of asset without path and .asset suffix</param>
	/// <returns>Instance</returns>
	public static T FindAsAssetInResourcesFolder(string assetname)
	{
		return instance = Resources.Load<T>(assetname);
	}
}